==> Paws-0.24.tar.gz: Paws-0.24/lib/Paws/Inspector/DescribeAssessmentRuns.pm <==

package Paws::Inspector::DescribeAssessmentRuns;
  use Moose;
  has AssessmentRunArns => (is => 'ro', isa => 'ArrayRef[Str]', traits => ['NameInRequest'], request_name => 'assessmentRunArns' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeAssessmentRuns');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Inspector::DescribeAssessmentRunsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeAssessmentRuns - Arguments for method DescribeAssessmentRuns on Paws::Inspector

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeAssessmentRuns on the 
Amazon Inspector service. Use the attributes of this class
as arguments to method DescribeAssessmentRuns.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeAssessmentRuns.

As an example:

  $service_obj->DescribeAssessmentRuns(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AssessmentRunArns => ArrayRef[Str]

The ARN(s) specifying the assessment run(s) that you want to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeAssessmentRuns in L<Paws::Inspector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.28.tar.gz: Paws-0.28/lib/Paws/Inspector/DescribeAssessmentRuns.pm <==

package Paws::Inspector::DescribeAssessmentRuns;
  use Moose;
  has AssessmentRunArns => (is => 'ro', isa => 'ArrayRef[Str]', traits => ['NameInRequest'], request_name => 'assessmentRunArns' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeAssessmentRuns');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Inspector::DescribeAssessmentRunsResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Inspector::DescribeAssessmentRuns - Arguments for method DescribeAssessmentRuns on Paws::Inspector

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeAssessmentRuns on the 
Amazon Inspector service. Use the attributes of this class
as arguments to method DescribeAssessmentRuns.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeAssessmentRuns.

As an example:

  $service_obj->DescribeAssessmentRuns(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> AssessmentRunArns => ArrayRef[Str]

The ARN that specifies the assessment run that you want to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeAssessmentRuns in L<Paws::Inspector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
